aboutsummaryrefslogtreecommitdiff
path: root/odb/session.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'odb/session.hxx')
-rw-r--r--odb/session.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/odb/session.hxx b/odb/session.hxx
index 1541fde..cfeebce 100644
--- a/odb/session.hxx
+++ b/odb/session.hxx
@@ -25,11 +25,11 @@ namespace odb
public:
typedef odb::database database_type;
// Set the current thread's session to this session. If another
// session is already in effect, throw the already_in_session
// exception.
//
- session ();
+ session (bool make_current = true);
// Reset the current thread's session if it is this session.
//
@@ -25,11 +25,11 @@ namespace odb
public:
typedef odb::database database_type;
- // Set the current thread's session to this session. If another
- // session is already in effect, throw the already_in_session
- // exception.
+ // If the make_current argument is true, then set the current thread's
+ // session to this session. If another session is already in effect,
+ // throw the already_in_session exception.
//